==> jc-1.4.0.tar.gz: gnu/java/security/x509/ext/BasicConstraints.h <==
// public class gnu.java.security.x509.ext.BasicConstraints

// class file dependencies
// @dep_class c18ef57daac52e01 gnu_java_security_x509_ext_BasicConstraints
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_BasicConstraints_H_
#define _JC_gnu_java_security_x509_ext_BasicConstraints_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_BasicConstraints$sub_refs	_jc_gnu_java_security_x509_ext_BasicConstraints$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_BasicConstraints$sub_nonrefs	_jc_gnu_java_security_x509_ext_BasicConstraints$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_BasicConstraints$refs	_jc_gnu_java_security_x509_ext_BasicConstraints$refs;
typedef struct _jc_gnu_java_security_x509_ext_BasicConstraints$nonrefs	_jc_gnu_java_security_x509_ext_BasicConstraints$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_BasicConstraints$object	_jc_gnu_java_security_x509_ext_BasicConstraints$object;

typedef struct _jc_gnu_java_security_x509_ext_BasicConstraints$fields_struct	_jc_gnu_java_security_x509_ext_BasicConstraints$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_BasicConstraints$vmethods	_jc_gnu_java_security_x509_ext_BasicConstraints$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_BasicConstraints$vtable	_jc_gnu_java_security_x509_ext_BasicConstraints$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_BasicConstraints$vtype	_jc_gnu_java_security_x509_ext_BasicConstraints$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_BasicConstraints$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24BasicConstraints;
};
extern _jc_gnu_java_security_x509_ext_BasicConstraints$fields_struct _jc_gnu_java_security_x509_ext_BasicConstraints$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_BasicConstraints$method$_init$9ff456f5359e4cdd(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *, jboolean, jint);
extern void _jc_gnu_java_security_x509_ext_BasicConstraints$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *, struct _jc_byte_array *);

// Virtual methods
extern _jc_byte_array *_jc_gnu_java_security_x509_ext_BasicConstraints$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *);
extern jint _jc_gnu_java_security_x509_ext_BasicConstraints$method$getPathLengthConstraint$a86f5758b30facd6(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *);
extern jboolean _jc_gnu_java_security_x509_ext_BasicConstraints$method$isCA$77fc088a76884e4b(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_BasicConstraints$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_BasicConstraints$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_x509_ext_BasicConstraints$method_info$getPathLengthConstraint$a86f5758b30facd6;
extern _jc_method _jc_gnu_java_security_x509_ext_BasicConstraints$method_info$isCA$77fc088a76884e4b;
extern _jc_method _jc_gnu_java_security_x509_ext_BasicConstraints$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_BasicConstraints$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_BasicConstraints$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_BasicConstraints$vmethods {
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *);
	jint	(*getPathLengthConstraint$a86f5758b30facd6)(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *);
	jboolean	(*isCA$77fc088a76884e4b)(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *);
};

// Vtable
struct _jc_gnu_java_security_x509_ext_BasicConstraints$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_BasicConstraints$vmethods	gnu_java_security_x509_ext_BasicConstraints;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_BasicConstraints$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_BasicConstraints$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_BasicConstraints$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_BasicConstraints$refs {
    _jc_gnu_java_security_x509_ext_BasicConstraints$sub_refs	gnu_java_security_x509_ext_BasicConstraints;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_BasicConstraints$sub_nonrefs {
	jboolean	ca;
	jint	pathLenConstraint;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_BasicConstraints$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_BasicConstraints$sub_nonrefs	gnu_java_security_x509_ext_BasicConstraints;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_BasicConstraints$object {
	_jc_gnu_java_security_x509_ext_BasicConstraints$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_BasicConstraints$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_BasicConstraints$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_BasicConstraints$vtype _jc_gnu_java_security_x509_ext_BasicConstraints$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_BasicConstraints, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_BasicConstraints$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_BasicConstraints_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/ext/BasicConstraints.h <==
// public class gnu.java.security.x509.ext.BasicConstraints

// class file dependencies
// @dep_class c18ef57daac52e01 gnu_java_security_x509_ext_BasicConstraints
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_BasicConstraints_H_
#define _JC_gnu_java_security_x509_ext_BasicConstraints_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_BasicConstraints$sub_refs	_jc_gnu_java_security_x509_ext_BasicConstraints$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_BasicConstraints$sub_nonrefs	_jc_gnu_java_security_x509_ext_BasicConstraints$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_BasicConstraints$refs	_jc_gnu_java_security_x509_ext_BasicConstraints$refs;
typedef struct _jc_gnu_java_security_x509_ext_BasicConstraints$nonrefs	_jc_gnu_java_security_x509_ext_BasicConstraints$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_BasicConstraints$object	_jc_gnu_java_security_x509_ext_BasicConstraints$object;

typedef struct _jc_gnu_java_security_x509_ext_BasicConstraints$fields_struct	_jc_gnu_java_security_x509_ext_BasicConstraints$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_BasicConstraints$vmethods	_jc_gnu_java_security_x509_ext_BasicConstraints$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_BasicConstraints$vtable	_jc_gnu_java_security_x509_ext_BasicConstraints$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_BasicConstraints$vtype	_jc_gnu_java_security_x509_ext_BasicConstraints$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_BasicConstraints$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24BasicConstraints;
};
extern _jc_gnu_java_security_x509_ext_BasicConstraints$fields_struct _jc_gnu_java_security_x509_ext_BasicConstraints$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_BasicConstraints$method$_init$9ff456f5359e4cdd(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *, jboolean, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_x509_ext_BasicConstraints$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_gnu_java_security_x509_ext_BasicConstraints$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_security_x509_ext_BasicConstraints$method$getPathLengthConstraint$a86f5758b30facd6(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_security_x509_ext_BasicConstraints$method$isCA$77fc088a76884e4b(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_BasicConstraints$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_BasicConstraints$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_x509_ext_BasicConstraints$method_info$getPathLengthConstraint$a86f5758b30facd6;
extern _jc_method _jc_gnu_java_security_x509_ext_BasicConstraints$method_info$isCA$77fc088a76884e4b;
extern _jc_method _jc_gnu_java_security_x509_ext_BasicConstraints$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_BasicConstraints$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_BasicConstraints$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_BasicConstraints$vmethods {
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *) _JC_JCNI_ATTR;
	jint	(*getPathLengthConstraint$a86f5758b30facd6)(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *) _JC_JCNI_ATTR;
	jboolean	(*isCA$77fc088a76884e4b)(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_BasicConstraints$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_x509_ext_BasicConstraints$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_BasicConstraints$vmethods	gnu_java_security_x509_ext_BasicConstraints;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_BasicConstraints$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_BasicConstraints$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_BasicConstraints$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_BasicConstraints$refs {
    _jc_gnu_java_security_x509_ext_BasicConstraints$sub_refs	gnu_java_security_x509_ext_BasicConstraints;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_BasicConstraints$sub_nonrefs {
	jboolean	ca;
	jint	pathLenConstraint;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_BasicConstraints$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_BasicConstraints$sub_nonrefs	gnu_java_security_x509_ext_BasicConstraints;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_BasicConstraints$object {
	_jc_gnu_java_security_x509_ext_BasicConstraints$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_BasicConstraints$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_BasicConstraints$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_BasicConstraints$vtype _jc_gnu_java_security_x509_ext_BasicConstraints$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_BasicConstraints, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_BasicConstraints$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_BasicConstraints_H_ */
